@@ -73,108 +73,13 @@ impl<'a> Section<'a> {
     build::SectionBuilderInit::new()
   }
 
-  /// Construct a Section block from a collection of text objects
-  ///
-  /// # Arguments
-  /// - `fields` - A collection of [text objects 🔗].
-  ///     Any text objects included with fields will be
-  ///     rendered in a compact format that allows for
-  ///     2 columns of side-by-side text.
-  ///     Maximum number of items is 10.
-  ///     Maximum length for the text in each item is 2000 characters.
-  ///
-  /// [text objects 🔗]: https://api.slack.com/reference/messaging/composition-objects#text
-  ///
-  /// # Errors
-  /// Doesn't error. To validate your model against the length requirements,
-  /// use the `validate` method.
-  ///
-  /// # Example
-  /// ```
-  /// use slack_blocks::{blocks, compose::text};
-  ///
-  /// # use std::error::Error;
-  /// # pub fn main() -> Result<(), Box<dyn Error>> {
-  /// let fields = vec!["Left column", "Right column"].into_iter()
-  ///                                                 .map(|s: &str| -> text::Text {
-  ///                                                   text::Plain::from(s).into()
-  ///                                                 })
-  ///                                                 .collect::<Vec<_>>();
-  ///
-  /// let block = blocks::Section::from_fields(&fields);
-  ///
-  /// // < send to slack API >
-  /// # Ok(())
-  /// # }
-  /// ```
-  pub fn from_fields<I>(fields: I) -> Self
-    where I: Into<Cow<'a, [text::Text]>>
-  {
-    let fields = Some(fields.into());
-
-    Self { fields,
-           text: None,
-           block_id: None,
-           accessory: None }
-  }
-
-  /// Construct a Section block from a text object
-  ///
-  /// # Arguments
-  /// - `text` - The text for the block, in the form of a [text object 🔗].
-  ///     Maximum length for the text in this field is 3000 characters.
-  ///
-  /// [text object 🔗]: https://api.slack.com/reference/messaging/composition-objects#text
-  ///
-  /// # Errors
-  /// Doesn't error. To validate your model against the length requirements,
-  /// use the `validate` method.
-  ///
-  /// # Example
-  /// ```
-  /// use slack_blocks::{blocks, compose::text};
-  ///
-  /// let block = blocks::Section::from_text(text::Plain::from("I am a section!"));
-  ///
-  /// // < send to slack API >
-  /// ```
-  pub fn from_text(text: impl Into<text::Text>) -> Self {
-    Self { text: Some(text.into()),
-           fields: None,
-           block_id: None,
-           accessory: None }
-  }
-
-  /// Set a unique `block_id` to identify this instance of an Section Block.
-  ///
-  /// # Arguments
-  ///
-  /// - `block_id` - A string acting as a unique identifier for a block.
-  ///     You can use this `block_id` when you receive an interaction
-  ///     payload to [identify the source of the action 🔗].
-  ///     If not specified, one will be generated.
-  ///     Maximum length for this field is 255 characters.
-  ///     `block_id` should be unique for each message and each iteration of a message.
-  ///     If a message is updated, use a new `block_id`.
-  ///
-  /// [identify the source of the action 🔗]: https://api.slack.com/interactivity/handling#payloads
-  pub fn with_block_id(mut self, block_id: impl Into<Cow<'a, str>>) -> Self {
-    self.block_id = Some(block_id.into());
-    self
-  }
-
   /// Validate that this Section block agrees with Slack's model requirements
   ///
   /// # Errors
-  /// - If `from_fields` was called with more than 10 fields,
-  ///     or one of the fields contains text longer than
-  ///     2000 chars
-  /// - If `from_fields` was called with one of the fields
-  ///     containing text longer than 2000 chars
-  /// - If `from_text` was called with text longer than
-  ///     3000 chars
-  /// - If `with_block_id` was called with a block id longer
-  ///     than 255 chars
+  /// - If `fields` contains more than 10 fields
+  /// - If one of `fields` longer than 2000 chars
+  /// - If `text` longer than 3000 chars
+  /// - If `block_id` longer than 255 chars
   ///
   /// # Example
   /// ```
@@ -182,13 +87,11 @@ impl<'a> Section<'a> {
   ///
   /// let long_string = std::iter::repeat(' ').take(256).collect::<String>();
   ///
-  /// let block = blocks::Section
-  ///     ::from_text(text::Plain::from("file_id"))
-  ///     .with_block_id(long_string);
+  /// let block = blocks::Section::builder().text(text::Plain::from("file_id"))
+  ///                                       .block_id(long_string)
+  ///                                       .build();
   ///
   /// assert_eq!(true, matches!(block.validate(), Err(_)));
-  ///
-  /// // < send to slack API >
   /// ```
   pub fn validate(&self) -> ValidationResult {
     Validate::validate(self)
@@ -221,14 +124,25 @@ pub mod build {
   ///
   /// # Required Methods
   /// `SectionBuilder::build()` is only available if these methods have been called:
-  ///  - `element`
+  ///  - `text` **or** `field(s)`, both may be called.
   ///
   /// # Example
   /// ```
-  /// use slack_blocks::{blocks::Section, elems::Image, text::ToSlackPlaintext};
+  /// use slack_blocks::{blocks::Section,
+  ///                    elems::Image,
+  ///                    text,
+  ///                    text::ToSlackPlaintext};
   ///
   /// let block =
   ///   Section::builder().text("foo".plaintext())
+  ///                     .field("bar".plaintext())
+  ///                     .field("baz".plaintext())
+  ///                     // alternatively:
+  ///                     .fields(vec!["bar".plaintext(),
+  ///                                  "baz".plaintext()]
+  ///                                  .into_iter()
+  ///                                  .map(text::Text::from)
+  ///                     )
   ///                     .accessory(Image::builder().image_url("foo.png")
   ///                                                .alt_text("pic of foo")
   ///                                                .build())
@@ -261,72 +175,82 @@ pub mod build {
       self
     }
 
-    /// Add `text` (**Required**, can be called many times)
+    /// Add `text` (**Required: this or `field(s)`**)
     ///
-    /// One or many [text objects 🔗] to populate the block with.
-    ///
-    /// # If called once:
-    /// Sets the `text` field of the section block.
+    /// The text for the block, in the form of a [text object 🔗].
     ///
     /// Maximum length for the text in this field is 3000 characters.
     ///
-    /// # If called multiple times:
-    /// Sets the `fields` field of the section block.
+    /// [text object 🔗]: https://api.slack.com/reference/messaging/composition-objects#text
+    pub fn text<T>(self, text: T) -> SectionBuilder<'a, Set<method::text>>
+      where T: Into<text::Text>
+    {
+      SectionBuilder { accessory: self.accessory,
+                       text: Some(text.into()),
+                       fields: self.fields,
+                       block_id: self.block_id,
+                       state: PhantomData::<_> }
+    }
+
+    /// Set `fields` (**Required: this or `text`**)
     ///
-    /// Fields will be rendered in a compact format that allows for
+    /// A collection of [text objects 🔗].
+    ///
+    /// Any text objects included with fields will be
+    /// rendered in a compact format that allows for
     /// 2 columns of side-by-side text.
+    ///
     /// Maximum number of items is 10.
     ///
     /// Maximum length for the text in each item is 2000 characters.
     ///
     /// [text objects 🔗]: https://api.slack.com/reference/messaging/composition-objects#text
-    pub fn text<T>(self, text: T) -> SectionBuilder<'a, Set<method::text>>
-      where T: Into<text::Text>
+    pub fn fields<I>(self, fields: I) -> SectionBuilder<'a, Set<method::text>>
+      where I: IntoIterator<Item = text::Text>
     {
-      let (text, fields) = match (self.text, self.fields) {
-        | (Some(t), None) => (None, Some(vec![t, text.into()])),
-        | (None, None) => (Some(text.into()), None),
-        | (None, Some(mut fs)) => {
-          fs.push(text.into());
-          (None, Some(fs))
-        },
-        | (Some(_), Some(_)) => {
-          unreachable!("fields and text should never both be set.")
-        },
-      };
-
       SectionBuilder { accessory: self.accessory,
-                       text,
-                       fields,
+                       text: self.text,
+                       fields: Some(fields.into_iter().collect()),
                        block_id: self.block_id,
                        state: PhantomData::<_> }
     }
 
-    /// Alias of `text` for XML macros, allowing fields
-    /// to be used as child elements.
+    /// Append a single field to `fields`.
+    pub fn field<T>(mut self, text: T) -> SectionBuilder<'a, Set<method::text>>
+      where T: Into<text::Text>
+    {
+      let mut fields = self.fields.take().unwrap_or_default();
+      fields.push(text.into());
+
+      self.fields(fields)
+    }
+
+    /// XML macro children, appends `fields` to the Section.
     ///
+    /// To set `text`, use the `text` attribute.
     /// ```
-    /// use mox::mox;
-    /// use slack_blocks::{mox::*, text};
+    /// use slack_blocks::{blocks::Section, blox::*, text, text::ToSlackPlaintext};
     ///
-    /// let as_attr = mox! {
-    ///   <section_block text={text::Plain::from("Foo")} />
-    /// };
-    ///
-    /// let as_child = mox! {
-    ///   <section_block>
+    /// let xml = blox! {
+    ///   <section_block text={"Section".plaintext()}>
     ///     <text kind=plain>"Foo"</text>
+    ///     <text kind=plain>"Bar"</text>
     ///   </section_block>
     /// };
     ///
-    /// assert_eq!(as_attr, as_child);
+    /// let equiv = Section::builder().text("Section".plaintext())
+    ///                               .field("Foo".plaintext())
+    ///                               .field("Bar".plaintext())
+    ///                               .build();
+    ///
+    /// assert_eq!(xml, equiv);
     /// ```
-    #[cfg(feature = "xml")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "xml")))]
+    #[cfg(feature = "blox")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "blox")))]
     pub fn child<T>(self, text: T) -> SectionBuilder<'a, Set<method::text>>
       where T: Into<text::Text>
     {
-      self.text(text)
+      self.field(text)
     }
 
     /// Set `block_id` (Optional)
@@ -381,6 +305,7 @@ pub mod build {
     }
   }
 }
+
 mod validate {
   use super::*;
   use crate::{compose::text,
