@@ -83,9 +83,11 @@ pub struct Opt<'a, T = AnyText, U = NoUrl> {
   value: Cow<'a, str>,
 
   #[validate(custom = "validate::desc")]
+  #[serde(skip_serializing_if = "Option::is_none")]
   description: Option<text::Text>,
 
   #[validate(custom = "validate::url")]
+  #[serde(skip_serializing_if = "Option::is_none")]
   url: Option<Cow<'a, str>>,
 
   #[serde(skip)]
@@ -108,9 +110,7 @@ impl<'a> Opt<'a> {
   ///
   /// # Examples
   /// ```
-  /// use std::convert::TryFrom;
-  ///
-  /// use slack_blocks::{blocks::Actions,
+  /// use slack_blocks::{blocks::{Actions, Block},
   ///                    compose::Opt,
   ///                    elems::{select::Static, BlockElement},
   ///                    text};
@@ -136,140 +136,16 @@ impl<'a> Opt<'a> {
   ///                  Opt::builder().text_plain(name).value(short_code).build()
   ///                });
   ///
-  /// let select: BlockElement =
-  ///   Static::builder().placeholder("Choose your favorite city!")
-  ///                    .action_id("fave_city")
-  ///                    .options(options)
-  ///                    .build()
-  ///                    .into();
+  /// let select = Static::builder().placeholder("Choose your favorite city!")
+  ///                               .action_id("fave_city")
+  ///                               .options(options)
+  ///                               .build();
   ///
-  /// let block = Actions::try_from(select);
+  /// let block: Block = Actions::builder().element(select).build().into();
   /// ```
   pub fn builder() -> build::OptBuilderInit<'a> {
     build::OptBuilderInit::new()
   }
-
-  /// Create an Option composition object from its label and
-  /// a value to be sent back to your app when it is chosen.
-  ///
-  /// This returns an `Opt` that can be used by
-  ///     overflow, select, and multi-select menus.
-  ///     To construct an `Opt` that can be used by
-  ///     radio buttons or checkboxes, see `from_mrkdwn_and_value`.
-  ///
-  /// # Arguments
-  ///
-  /// - `text` - A [text object 🔗] that defines the text shown in the option on the menu.
-  ///     Overflow, select, and multi-select menus
-  ///     can only use `plain_text` objects,
-  ///     while radio buttons and checkboxes
-  ///     can use `mrkdwn` text objects.
-  ///     Maximum length for the `text` in this field is 75 characters.
-  ///
-  /// - `value` - The string value that will be passed to your app
-  ///     when this option is chosen.
-  ///     Maximum length for this field is 75 characters.
-  ///
-  /// [text object 🔗]: https://api.slack.com#text
-  ///
-  /// # Examples
-  /// ```
-  /// use slack_blocks::text;
-  /// use slack_blocks::blocks::Block;
-  /// use slack_blocks::blocks::Section;
-  /// use slack_blocks::blocks::Actions;
-  /// use slack_blocks::compose::Opt;
-  ///
-  /// let cities = vec![
-  ///   ("San Francisco", "san_francisco"),
-  ///   ("San Diego", "san_diego"),
-  ///   ("New York City", "nyc"),
-  ///   ("Phoenix", "phx"),
-  ///   ("Boston", "boston"),
-  ///   ("Seattle", "seattle"),
-  /// ]
-  ///     .into_iter()
-  ///     .map(|(title, short_code)| Opt::from_plain_text_and_value(title, short_code))
-  ///     .collect::<Vec<_>>();
-  ///
-  /// let blocks: Vec<Block> = vec![
-  ///   Section::from_text(text::Plain::from("Choose your favorite city...")).into(),
-  ///   Actions::from_action_elements(vec![]).into() // TODO: add overflow to this example once it exists
-  /// ];
-  ///
-  /// // < send block to slack's API >
-  /// ```
-  #[deprecated(since = "0.15.0", note = "Use Opt::builder instead")]
-  pub fn from_plain_text_and_value(text: impl Into<text::Plain>,
-                                   value: impl Into<Cow<'a, str>>)
-                                   -> Opt<'a, text::Plain, NoUrl> {
-    Opt { text: text.into().into(),
-          value: value.into(),
-          description: None,
-          url: None,
-          marker: std::marker::PhantomData }
-  }
-
-  /// Create an Option composition object from its label and
-  /// a value to be sent back to your app when it is chosen.
-  ///
-  /// This returns an `Opt` that can be used by
-  ///     radio buttons or checkboxes.
-  ///     To construct an `Opt` that can be used by
-  ///     overflow, select, and multi-select menus,
-  ///     see `from_plain_text_and_value`.
-  ///
-  /// # Arguments
-  ///
-  /// - `text` - A [text object 🔗] that defines the text shown in the option on the menu.
-  ///     Overflow, select, and multi-select menus
-  ///     can only use `plain_text` objects,
-  ///     while radio buttons and checkboxes
-  ///     can use `mrkdwn` text objects.
-  ///     Maximum length for the `text` in this field is 75 characters.
-  ///
-  /// - `value` - The string value that will be passed to your app
-  ///     when this option is chosen.
-  ///     Maximum length for this field is 75 characters.
-  ///
-  /// [text object 🔗]: https://api.slack.com#text
-  ///
-  /// # Examples
-  /// ```
-  /// use slack_blocks::text;
-  /// use slack_blocks::blocks::Block;
-  /// use slack_blocks::blocks::Section;
-  /// use slack_blocks::blocks::Actions;
-  /// use slack_blocks::compose::Opt;
-  ///
-  /// let options = vec![
-  ///     "1",
-  ///     "2",
-  ///     "3",
-  ///     "4",
-  ///     "5",
-  /// ]
-  ///     .into_iter()
-  ///     .map(|num| Opt::from_mrkdwn_and_value(num, num))
-  ///     .collect::<Vec<_>>();
-  ///
-  /// let blocks: Vec<Block> = vec![
-  ///   Section::from_text(text::Plain::from("On a scale from 1 to 5...")).into(),
-  ///   Actions::from_action_elements(vec![]).into() // TODO: add radio buttons to this example once it exists
-  /// ];
-  ///
-  /// // < send block to slack's API >
-  /// ```
-  #[deprecated(since = "0.15.0", note = "Use Opt::builder instead")]
-  pub fn from_mrkdwn_and_value(text: impl Into<text::Mrkdwn>,
-                               value: impl Into<Cow<'a, str>>)
-                               -> Opt<'a, text::Mrkdwn, NoUrl> {
-    Opt { text: text.into().into(),
-          value: value.into(),
-          description: None,
-          url: None,
-          marker: std::marker::PhantomData }
-  }
 }
 
 impl<'a, U> Opt<'a, text::Plain, U> {
@@ -285,64 +161,14 @@ impl<'a, U> Opt<'a, text::Plain, U> {
 
 // Methods available to all specializations
 impl<'a, T, U> Opt<'a, T, U> {
-  /// Chainable setter method, that sets a description for this `Opt`.
-  ///
-  /// # Arguments
-  ///
-  /// - `desc` - A [`plain_text` only text object 🔗] that defines
-  ///     a line of descriptive text shown below the `text` field
-  ///     beside the radio button.
-  ///     Maximum length for the `text` object within this field
-  ///     is 75 characters.
-  ///
-  /// [`plain_text` only text object 🔗]: https://api.slack.com/reference/block-kit/composition-objects#text
-  ///
-  /// # Example
-  ///
-  /// ```
-  /// use slack_blocks::text;
-  /// use slack_blocks::blocks::Block;
-  /// use slack_blocks::blocks::Section;
-  /// use slack_blocks::blocks::Actions;
-  /// use slack_blocks::compose::Opt;
-  ///
-  /// let options = vec![
-  ///     ("1", "Hated it."),
-  ///     ("2", "Didn't like it."),
-  ///     ("3", "It was OK."),
-  ///     ("4", "Liked it!"),
-  ///     ("5", "New favorite!!"),
-  /// ]
-  ///     .into_iter()
-  ///     .map(|(num, desc)| {
-  ///         Opt::from_mrkdwn_and_value(num, num)
-  ///             .with_description(desc)
-  ///     })
-  ///     .collect::<Vec<_>>();
-  ///
-  /// let blocks: Vec<Block> = vec![
-  ///   Section::from_text(text::Plain::from("On a scale from 1 to 5...")).into(),
-  ///   Actions::from_action_elements(vec![]).into() // TODO: add radio buttons to this example once it exists
-  /// ];
-  ///
-  /// // < send block to slack's API >
-  /// ```
-  #[deprecated(since = "0.15.0", note = "Use Opt::builder instead")]
-  pub fn with_description(mut self, desc: impl Into<text::Plain>) -> Self {
-    self.description = Some(desc.into().into());
-    self
-  }
-
   /// Validate that this Option composition object
   /// agrees with Slack's model requirements
   ///
   /// # Errors
-  /// - If `from_plain_text_and_value` or `from_mrkdwn_and_value`
-  ///     was called with `text` longer than 75 chars
-  /// - If `from_plain_text_and_value` or `from_mrkdwn_and_value`
-  ///     was called with `value` longer than 75 chars
-  /// - If `with_url` was called with url longer than 3000 chars
-  /// - If `with_description` was called with text longer than 75 chars
+  /// - If `text` longer than 75 chars
+  /// - If `value` longer than 75 chars
+  /// - If `url` longer than 3000 chars
+  /// - If `description` longer than 75 chars
   ///
   /// # Example
   /// ```
@@ -352,7 +178,9 @@ impl<'a, T, U> Opt<'a, T, U> {
   ///
   /// let long_string: String = repeat(' ').take(76).collect();
   ///
-  /// let opt = Opt::from_plain_text_and_value("My Option", long_string);
+  /// let opt = Opt::builder().text_plain("My Option")
+  ///                         .value(long_string)
+  ///                         .build();
   ///
   /// assert_eq!(true, matches!(opt.validate(), Err(_)));
   /// ```
@@ -361,65 +189,6 @@ impl<'a, T, U> Opt<'a, T, U> {
   }
 }
 
-// Methods available only to `Opt` created from `text::Plain`
-impl<'a, U> Opt<'a, text::Plain, U> {
-  /// Chainable setter method, that sets a url for this `Opt`.
-  ///
-  /// **The `url` attribute is only available in [overflow menus 🔗]**.
-  ///
-  /// If you're using `url`, you'll still receive an [interaction payload 🔗]
-  /// and will need to [send an acknowledgement response 🔗].
-  ///
-  /// # Arguments
-  /// - `url` - A URL to load in the user's browser when the option is clicked.
-  ///     Maximum length for this field is 3000 characters.
-  ///
-  /// [overflow menus 🔗]: https://api.slack.com/reference/block-kit/block-elements#overflow
-  /// [interaction payload 🔗]: https://api.slack.com/interactivity/handling#payloads
-  /// [send an acknowledgement response 🔗]: https://api.slack.com/interactivity/handling#acknowledgment_response
-  ///
-  /// # Example
-  /// ```
-  /// use slack_blocks::text;
-  /// use slack_blocks::blocks::Block;
-  /// use slack_blocks::blocks::Section;
-  /// use slack_blocks::blocks::Actions;
-  /// use slack_blocks::compose::Opt;
-  ///
-  /// let cities = vec![
-  ///   ("San Francisco", "san_francisco", "https://www.sftravel.com/"),
-  ///   ("San Diego", "san_diego", "https://www.sandiego.org/explore.aspx"),
-  ///   ("New York City", "nyc", "https://www.nycgo.com/"),
-  ///   ("Phoenix", "phx", "https://www.visitphoenix.com/"),
-  ///   ("Boston", "boston", "https://www.boston.gov/visiting-boston"),
-  ///   ("Seattle", "seattle", "https://visitseattle.org/"),
-  /// ]
-  ///     .into_iter()
-  ///     .map(|(title, short_code, travel_link)| {
-  ///         Opt::from_plain_text_and_value(title, short_code)
-  ///             .with_url(travel_link)
-  ///     })
-  ///     .collect::<Vec<_>>();
-  ///
-  /// let blocks: Vec<Block> = vec![
-  ///   Section::from_text(text::Plain::from("Choose your favorite city...")).into(),
-  ///   Actions::from_action_elements(vec![]).into() // TODO: add overflow to this example once it exists
-  /// ];
-  ///
-  /// // < send block to slack's API >
-  /// ```
-  #[deprecated(since = "0.15.0", note = "Use Opt::builder instead")]
-  pub fn with_url(self,
-                  url: impl Into<Cow<'a, str>>)
-                  -> Opt<'a, text::Plain, AllowUrl> {
-    Opt { text: self.text,
-          value: self.value,
-          description: self.description,
-          url: Some(url.into()),
-          marker: std::marker::PhantomData }
-  }
-}
-
 /// Opt builder
 pub mod build {
   use std::marker::PhantomData;
@@ -471,16 +240,13 @@ pub mod build {
   ///                      Opt::builder().text_plain(name).value(code).build()
   ///                    });
   ///
-  /// let select: BlockElement =
+  /// let select =
   ///   Static::builder().placeholder("Choose your favorite programming language!")
   ///                    .options(langs)
   ///                    .action_id("lang_chosen")
-  ///                    .build()
-  ///                    .into();
+  ///                    .build();
   ///
-  /// let block: Block =
-  ///   Actions::try_from(select).expect("actions supports select elements")
-  ///                            .into();
+  /// let block: Block = Actions::builder().element(select).build().into();
   ///
   /// // <send block to API>
   /// ```
@@ -550,10 +316,9 @@ pub mod build {
   impl<'a, V, U> OptBuilder<'a, RequiredMethodNotCalled<method::text>, V, U> {
     /// Alias for `text`, allowing you to set the text of the option like so:
     /// ```
-    /// use mox::mox;
-    /// use slack_blocks::{compose::Opt, mox::*, text};
+    /// use slack_blocks::{blox::*, compose::Opt, text};
     ///
-    /// let xml = mox! {
+    /// let xml = blox! {
     ///   <option value="foo">
     ///     <text kind=plain>"Foo"</text>
     ///   </option>
@@ -565,8 +330,8 @@ pub mod build {
     ///
     /// assert_eq!(xml, equiv)
     /// ```
-    #[cfg(feature = "xml")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "xml")))]
+    #[cfg(feature = "blox")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "blox")))]
     pub fn child<T: Into<text::Text>>(
       self,
       text: T)
