@@ -30,10 +30,16 @@ use crate::{compose::Confirm, text, val_helpr::*};
 pub struct DatePicker<'a> {
   #[validate(length(max = 255))]
   action_id: Cow<'a, str>,
+
   #[validate(custom = "validate_placeholder")]
+  #[serde(skip_serializing_if = "Option::is_none")]
   placeholder: Option<text::Text>,
+
+  #[serde(skip_serializing_if = "Option::is_none")]
   initial_date: Option<String>,
+
   #[validate]
+  #[serde(skip_serializing_if = "Option::is_none")]
   confirm: Option<Confirm>,
 }
 
@@ -93,10 +99,9 @@ pub mod build {
   /// use slack_blocks::{blocks::{Actions, Block},
   ///                    elems::{BlockElement, DatePicker}};
   ///
-  /// let picker: BlockElement =
-  ///   DatePicker::builder().action_id("foo").build().into();
+  /// let picker = DatePicker::builder().action_id("foo").build();
   ///
-  /// let block: Block = Actions::try_from(picker).unwrap().into();
+  /// let block: Block = Actions::builder().element(picker).build().into();
   ///
   /// // <send block to slack API>
   /// ```
@@ -168,7 +173,7 @@ pub mod build {
     ///                      .build();
     /// ```
     pub fn initial_date(mut self, (day, month, year): (u8, u8, u16)) -> Self {
-      self.initial_date = Some(format!("{}-{}-{}", year, month, day));
+      self.initial_date = Some(format!("{:02}-{:02}-{}", year, month, day));
       self
     }
 
