@@ -46,7 +46,7 @@ pub struct Static<'a> {
   #[validate]
   confirm: Option<Confirm>,
 
-  // Select One
+  #[serde(skip_serializing_if = "Option::is_none")]
   initial_option: Option<StaticOptOrOptGroup<'a>>,
 }
 
@@ -83,14 +83,12 @@ impl<'a> Static<'a> {
   ///                  Opt::builder().text_plain(name).value(short_code).build()
   ///                });
   ///
-  /// let select: BlockElement =
-  ///   Static::builder().placeholder("Choose your favorite city!")
-  ///                    .action_id("fave_city")
-  ///                    .options(options)
-  ///                    .build()
-  ///                    .into();
+  /// let select = Static::builder().placeholder("Choose your favorite city!")
+  ///                               .action_id("fave_city")
+  ///                               .options(options)
+  ///                               .build();
   ///
-  /// let block: Block = Actions::try_from(select).unwrap().into();
+  /// let block: Block = Actions::builder().element(select).build().into();
   /// ```
   pub fn builder() -> build::StaticBuilderInit<'a> {
     build::StaticBuilderInit::new()
@@ -168,18 +166,15 @@ pub mod build {
   ///                    compose::Opt,
   ///                    elems::{select::Static, BlockElement}};
   ///
-  /// let rust = Opt::from_plain_text_and_value("Rust", "rs");
+  /// let rust = Opt::builder().text_plain("Rust").value("rs").build();
   ///
-  /// let select: BlockElement =
+  /// let select =
   ///   Static::builder().placeholder("Choose your favorite programming language!")
   ///                    .options(vec![rust])
   ///                    .action_id("lang_chosen")
-  ///                    .build()
-  ///                    .into();
+  ///                    .build();
   ///
-  /// let block: Block =
-  ///   Actions::try_from(select).expect("actions supports select elements")
-  ///                            .into();
+  /// let block: Block = Actions::builder().element(select).build().into();
   ///
   /// // <send block to API>
   /// ```
@@ -198,8 +193,8 @@ pub mod build {
 
   /// Allows the builder to statically take in "either an opt or opt group" and
   /// enforce that the same type is used as a child later.
-  #[cfg(feature = "xml")]
-  #[cfg_attr(docsrs, doc(cfg(feature = "xml")))]
+  #[cfg(feature = "blox")]
+  #[cfg_attr(docsrs, doc(cfg(feature = "blox")))]
   pub trait AppendOptOrOptGroup<'a, Multi, Placeholder, ActionId> {
     /// The builder state after adding the opt / opt group
     type Output;
@@ -214,8 +209,8 @@ pub mod build {
               -> Self::Output;
   }
 
-  #[cfg(feature = "xml")]
-  #[cfg_attr(docsrs, doc(cfg(feature = "xml")))]
+  #[cfg(feature = "blox")]
+  #[cfg_attr(docsrs, doc(cfg(feature = "blox")))]
   impl<'a, Multi, Placeholder, ActionId>
     AppendOptOrOptGroup<'a, Multi, Placeholder, ActionId>
     for Opt<'a, text::Plain, NoUrl>
@@ -236,8 +231,8 @@ pub mod build {
     }
   }
 
-  #[cfg(feature = "xml")]
-  #[cfg_attr(docsrs, doc(cfg(feature = "xml")))]
+  #[cfg(feature = "blox")]
+  #[cfg_attr(docsrs, doc(cfg(feature = "blox")))]
   impl<'a, Multi, Placeholder, ActionId>
     AppendOptOrOptGroup<'a, Multi, Placeholder, ActionId>
     for OptGroup<'a, text::Plain, NoUrl>
@@ -462,8 +457,8 @@ pub mod build {
     /// The type signature trickery here infers whether you've passed
     /// an Opt or OptGroup, and will ensure the following children will
     /// be the same type.
-    #[cfg(feature = "xml")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "xml")))]
+    #[cfg(feature = "blox")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "blox")))]
     pub fn child<Opt>(self, child: Opt) -> Opt::Output
       where Opt: AppendOptOrOptGroup<'a, M, P, A>
     {
@@ -538,8 +533,8 @@ pub mod build {
     }
 
     /// Append an Opt as a child XML element.
-    #[cfg(feature = "xml")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "xml")))]
+    #[cfg(feature = "blox")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "blox")))]
     pub fn child(self, option: impl Into<StaticOpt<'a>>) -> Self {
       self.option(option)
     }
@@ -559,8 +554,8 @@ pub mod build {
     }
 
     /// Append an OptGroup as a child XML element.
-    #[cfg(feature = "xml")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "xml")))]
+    #[cfg(feature = "blox")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "blox")))]
     pub fn child(self, option: impl Into<StaticOptGroup<'a>>) -> Self {
       self.option_group(option)
     }
